spawn_dev_server

Function spawn_dev_server 

pub fn spawn_dev_server(config: &ViteConfig) -> Result<DevServerHandle>
Spawns the Vite dev server as a child process.

Returns a DevServerHandle that kills the process on drop. This should only be called in debug mode and when auto_start is enabled.